@@ -182,8 +182,8 @@ class tscausalinference:
                         color = 'orange', legend = False, ax=axes[0])
 
         sns.lineplot(x = 'ds', y = 'y', color = 'b',
-                    ax=axes[0],
-                    data = data[(data.ds >= pd.to_datetime(self.intervention[0]) - pd.Timedelta(days=self.back_window))],
+                    err_kws={'linestyle': '--', 'hatch': '///', 'fc': 'none'}, ax=axes[0],
+                    data = data[(data.ds <= pd.to_datetime(self.intervention[0]))],
                     linewidth=1, label='Training')
 
         sns.lineplot(x = 'ds', y = 'yhat', color = 'b',
@@ -192,6 +192,7 @@ class tscausalinference:
                     linewidth=1, label='Forcast', ls='--', ax=axes[0])
 
         sns.lineplot(x = 'ds', y = 'y', color = 'g',
+                    err_kws={'linestyle': '--', 'hatch': '///', 'fc': 'none'},
                     data = data[(data.ds >= pd.to_datetime(self.intervention[0]))&(data.ds <= pd.to_datetime(self.intervention[1]))],
                     label='Real', ax=axes[0])
         
