@@ -1,3 +1,5 @@
+from typing import Any, Dict, List, Optional, Tuple, Union
+
 from prophet import Prophet
 
 from prophet.diagnostics import cross_validation
@@ -7,33 +9,25 @@ from prophet.utilities import regressor_coefficients
 from tabulate import tabulate
 from sklearn.metrics import r2_score, mean_absolute_error
 
+from tscausalinference.evaluators import mape
+
 import pandas as pd
 from pandas import DataFrame
 
-import numpy as np
-
-import itertools
-
 import logging
 
-from tscausalinference.evaluators import mape
-
 logger = logging.getLogger('cmdstanpy')
 logger.addHandler(logging.NullHandler())
 logger.propagate = False
 logger.setLevel(logging.CRITICAL)
 
-logging.getLogger('fbprophet').setLevel(logging.ERROR)
-
-pd.options.mode.chained_assignment = None 
-
 def synth_analysis(df: DataFrame = None, 
                     regressors: list = [], 
                     intervention: list = None, 
-                    cross_validation_steps: int = 5,
-                    alpha: float = 0.05,
-                    model_params: dict = {}
+                    seasonality: bool = True,
+                    cross_validation_steps: int = 5
                     ):
+
     """
     A function to analyze a dataset using the Prophet library and provide evaluation metrics, response metrics and 
     intervention metrics. 
@@ -87,6 +81,27 @@ def synth_analysis(df: DataFrame = None,
     | regressor_2   |         -0.0133  |
     +---------------+------------------+
 
+    Pre-Intervention response metrics ->
+    +---------+-------+
+    | Metric  | Value |
+    +=========+=======+
+    | r2      |  0.73 |
+    +---------+-------+
+    | MAE     | 34.92 |
+    +---------+-------+
+    | MAPE (%)| 15.21 |
+    +---------+-------+
+
+    Intervention metrics ->
+    +------------------------+--------+
+    | Metric                 | Value  |
+    +========================+========+
+    | Actual cumulative      | 156874 |
+    +------------------------+--------+
+    | Predicted cumulative:  | 163998 |
+    +------------------------+--------+
+    | Difference             |  7124  |
+    +------------------------+--------+
     """
 
     if not isinstance(df, pd.DataFrame):
@@ -98,23 +113,7 @@ def synth_analysis(df: DataFrame = None,
 
     if isinstance(intervention, type(None)):
       intervention_error = 'Define your intervention as a list with the start_date and end_date of your intervention'
-      raise TypeError(intervention_error)
-    
-    if len(model_params) < 1:
-        model_parameters = {
-                'changepoint_range': 0.85,
-                'yearly_seasonality': True,
-                'weekly_seasonality': True,
-                'daily_seasonality': False,
-                'holidays': None,
-                'seasonality_mode': 'additive',
-                'changepoint_prior_scale': 0.05,
-                'mcmc_samples': 1000,
-                'interval_width': 1 - alpha}
-        
-        print('Default parameters grid: \n{}',format(model_parameters))
-    else:
-        model_parameters = model_params.copy()
+      raise intervention_error
     
     pre_intervention = [df.ds.min(),(pd.to_datetime(intervention[0]) - pd.Timedelta(days=1)).strftime('%Y-%m-%d')]
     post_intervention = [(pd.to_datetime(intervention[0]) + pd.Timedelta(days=1)).strftime('%Y-%m-%d'),df.ds.max()]
@@ -129,41 +128,15 @@ def synth_analysis(df: DataFrame = None,
 
     print('Training period: {} to {}'.format(pre_intervention[0], pre_intervention[1]))
     print('Test period: {} to {}\n'.format(intervention[0], intervention[1]))
-    print('Prediction horizon: {} days'.format(prediction_period))
-    
-    condition_int = isinstance(model_parameters[list(model_parameters.keys())[0]], float)
-    condition_float = isinstance(model_parameters[list(model_parameters.keys())[0]], int)
-    condition_str = isinstance(model_parameters[list(model_parameters.keys())[0]], str)
-    
-    if not (condition_int)|(condition_float)|(condition_str):
-        print('Grid Search Cross-Validation mode:\n')
-        if isinstance(model_parameters[list(model_parameters.keys())[0]], list):
-            # Generate all combinations of parameters
-            all_params = [dict(zip(model_parameters.keys(), v)) for v in itertools.product(*model_parameters.values())]
-            rmses = []  # Store the RMSEs for each params here
 
-            # Use cross validation to evaluate all parameters
-            for params in all_params:
-                m = Prophet(**params).fit(training_dataframe)  # Fit model with given params
-                df_cv = cross_validation(m, '{} days'.format(cross_validation_steps), disable_tqdm=False , parallel="processes")
-                df_p = performance_metrics(df_cv, rolling_window=1)
-                rmses.append(df_p['rmse'].mean())
-
-            # Find the best parameters
-            tuning_results = pd.DataFrame(all_params)
-            tuning_results['rmse'] = rmses
-            # Python
-            best_params = all_params[np.argmin(rmses)]
-            print(best_params)
-            
-            prophet = Prophet(**best_params)
-        else:
-            raise TypeError("Your parameters on the Grid are not list type")
-    
+    if seasonality:
+        prophet = Prophet(daily_seasonality=True, 
+                    weekly_seasonality=True, 
+                    changepoint_prior_scale = 0.05, 
+                    changepoint_range = 0.85)
     else:
-        model_parameters.update({'interval_width': 1 - alpha})
-        print('Custom parameters grid: \n{}',format(model_parameters))
-        prophet = Prophet(**model_parameters)
+        prophet = Prophet(changepoint_prior_scale = 0.05, 
+                    changepoint_range = 0.85)
 
     for regressor in regressors:
             prophet.add_regressor(name = regressor)
@@ -180,7 +153,7 @@ def synth_analysis(df: DataFrame = None,
     df['ds'] = pd.to_datetime(df['ds'])
 
     data = pd.merge(
-        prophet_predict[['ds','yhat', 'yhat_lower', 'yhat_upper', 'trend']+list(prophet.seasonalities.keys())], 
+        prophet_predict[['ds','yhat', 'yhat_lower', 'yhat_upper']], 
         df[["ds", "y"]], how='left', on='ds'
         )
 
@@ -197,44 +170,35 @@ def synth_analysis(df: DataFrame = None,
     data['cummulitive_yhat_upper'] = data['yhat_upper'].cumsum()
 
     # print response
-    print(f'\nCross-validation MAPE: {model_mape_mean:.2%}')
-    print('\nSeasons detected: {}'.format(list(prophet.seasonalities.keys())))
+    print(f'Cross-validation MAPE: {model_mape_mean:.2%}')
     if len(regressors) >= 1:
         regressor_df = regressor_coefficients(prophet)
         # format table
         table = []
         for index, row in regressor_df.iterrows():
-            table.append([index, *list(row.values)])
+            table.append([index, row])
+
+        print(tabulate(table, headers=['Regressor', 'Coefficient'], tablefmt='grid'))
 
-        print(tabulate(table, headers=['Regressor', 'Regressor Mode', 'Center', 'Coef. Lower', 'Coef', 'Coef. Upper'], tablefmt='grid'))
-    
     pre_int_metrics = [
-    ['r2', r2_score(y_pred = data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].yhat, y_true = data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].y)],
-    ['MAE', mean_absolute_error(y_pred = data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].yhat, y_true = data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].y)],
-    ['MAPE (%)', mape(y_pred = data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].yhat, y_true = data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].y)],
-    ['Noise (Std)', np.std(data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].y - data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].yhat)]
+    ['r2', r2_score(y_pred = data[(data.ds > pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].yhat, y_true = data[(data.ds > pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].y)],
+    ['MAE', mean_absolute_error(y_pred = data[(data.ds > pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].yhat, y_true = data[(data.ds > pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].y)],
+    ['MAPE (%)', mape(y_pred = data[(data.ds > pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].yhat, y_true = data[(data.ds > pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].y)]
     ]
 
-    strings_info = """
-+------------------------+
-Pre intervention metrics
-+------------------------+
-{}
-    """
-
-    print(
-        strings_info.format(
-            tabulate(pre_int_metrics, 
-            headers=['Metric', 'Value'], 
-            tablefmt='pipe')
-        ).strip()
-    )
+    print('\nPre-Intervention response metrics ->')
+    print(tabulate(pre_int_metrics, headers=['Metric', 'Value'], tablefmt='grid'))
 
     int_metrics = [
-    ['Actual cumulative', data[(data.ds >= intervention[0]) & (data.ds <= intervention[1])].y.sum()],
-    ['Predicted cumulative:', data[(data.ds >= intervention[0]) & (data.ds <= intervention[1])].yhat.sum()],
-    ['Difference', data[(data.ds >= intervention[0]) & (data.ds <= intervention[1])].point_effects.sum()],
-    ['Change (%)', (data[(data.ds >= intervention[0]) & (data.ds <= intervention[1])].y.sum() / data[(data.ds >= intervention[0]) & (data.ds <= intervention[1])].yhat.sum() -1)*100]
+    ['Actual cumulative', data[(data.ds >= intervention[0]) & (data.ds < intervention[1])].y.sum()],
+    ['Predicted cumulative:', data[(data.ds >= intervention[0]) & (data.ds < intervention[1])].yhat.sum()],
+    ['Difference', data[(data.ds >= intervention[0]) & (data.ds < intervention[1])].point_effects.sum()],
+    ['Change (%)', (data[(data.ds >= intervention[0]) & (data.ds < intervention[1])].y.sum() / data[(data.ds >= intervention[0]) & (data.ds < intervention[1])].yhat.sum() -1)*100]
     ]
-    
-    return data, pre_int_metrics, int_metrics
\ No newline at end of file
+
+    print('\nIntervention response metrics ->')
+    print('Prediction Period {}'.format(prediction_period))
+    print('CI 95%: [{}, {}]'.format(data[(data.ds >= intervention[0]) & (data.ds < intervention[1])].yhat_lower.sum(), data[(data.ds >= intervention[0]) & (data.ds < intervention[1])].yhat_upper.sum()))
+    print(tabulate(int_metrics, headers=['Metric', 'Value'], tablefmt='grid'))
+
+    return data
\ No newline at end of file
